Trait Notifier

pub trait Notifier:
    Send
    + Sync
    + 'static {
    // Required methods
    fn request_redraw(&self);
    fn invalidate_layout(&self);
}
A type that can notify a shell of certain events.

Required Methods

fn request_redraw(&self)

Requests for all windows of the Shell to be redrawn.

fn invalidate_layout(&self)

Requests for all layouts of the Shell to be recomputed.

Implementations on Foreign Types



impl<T> Notifier for Proxy<T>
where T: Send,

Implementors